==> haskell-data-default-0.7.1.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default
version: 0.7.1.1
id: data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
key: data-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
license: BSD-3-Clause
maintainer: <l.mai@web.de>
author: Lukas Mai
synopsis: A class for types with a default value
category: Data
abi: df69bf1546f6b4e11e877584feeeb61a
exposed: True
exposed-modules:
    Data.Default
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-0.7.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/data-default-0.7.1.1
hs-libraries: HSdata-default-0.7.1.1-6pNGRUfj5nU7unWVd8ajT0
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    data-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA
    data-default-instances-dlist-0.0.1-GGmGGHeumpsJkK5tXKqXXv
    data-default-instances-old-locale-0.0.1-GoLpzNLZpWmDQs8Y0CLH4y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             data-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA=b0c95f415e57b99d6acab6b1f7f56958
             data-default-instances-dlist-0.0.1-GGmGGHeumpsJkK5tXKqXXv=b2bbecfce1acd61fa41491430ecd68d3
             data-default-instances-old-locale-0.0.1-GoLpzNLZpWmDQs8Y0CLH4y=45e7aadd861a944eb111cf8d2cc66d11
haddock-interfaces: /usr/share/doc/haskell-data-default/html/data-default.haddock
haddock-html: /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-default-0.7.1.1-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-default
version: 0.7.1.1
id: data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
key: data-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
license: BSD-3-Clause
maintainer: <l.mai@web.de>
author: Lukas Mai
synopsis: A class for types with a default value
category: Data
abi: 0b9cf97a5dc28f689e30b5244977846e
exposed: True
exposed-modules:
    Data.Default
import-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-0.7.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/data-default-0.7.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/data-default-0.7.1.1
hs-libraries: HSdata-default-0.7.1.1-ANph70WEdAe9A1H2IGNxHn
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    data-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA
    data-default-instances-dlist-0.0.1-AHcGTNiXruW3PEDvkkFNp5
    data-default-instances-old-locale-0.0.1-GoLpzNLZpWmDQs8Y0CLH4y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=64b4bc7e44050b1acf530e79a106effe
             data-default-instances-containers-0.0.1-EuylP0qAiv52WAOyUJkumA=b0c95f415e57b99d6acab6b1f7f56958
             data-default-instances-dlist-0.0.1-AHcGTNiXruW3PEDvkkFNp5=395d1887b953adc9498865c6058512ff
             data-default-instances-old-locale-0.0.1-GoLpzNLZpWmDQs8Y0CLH4y=45e7aadd861a944eb111cf8d2cc66d11
haddock-interfaces: /usr/share/doc/haskell-data-default/html/data-default.haddock
haddock-html: /usr/share/doc/haskell-data-default/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
